@@ -18,6 +18,7 @@ from ..util import (
     run_default_filter,
     untis_colour_to_hex,
     untis_split_first,
+    untis_split_second,
 )
 
 logger = logging.getLogger(__name__)
@@ -380,7 +381,7 @@ def import_supervision_areas(
         supervisions_ref = {}
         for raw_supervision in raw_supervisions:
             # Split more and get teacher id
-            raw_supervision_2 = raw_supervision.split("~")
+            raw_supervision_2 = untis_split_second(raw_supervision, remove_empty=False)
             teacher_id = int(raw_supervision_2[1])
             term_id = int(raw_supervision_2[0])
 
