@@ -19,6 +19,8 @@ from ..util import (
     compare_m2m,
     connect_untis_fields,
     run_default_filter,
+    untis_split_first,
+    untis_split_second,
     untis_split_third,
 )
 
@@ -51,12 +53,12 @@ def import_lessons(
 
         # Split data (,)
         raw_lesson_data = connect_untis_fields(lesson, "lessonelement", 10)
-        raw_time_data = lesson.lesson_tt.split(",")
+        raw_time_data = untis_split_first(lesson.lesson_tt, remove_empty=False)
 
         raw_time_data_2 = []
         for el in raw_time_data:
             # Split data (~)
-            raw_time_data_2.append(el.split("~"))
+            raw_time_data_2.append(untis_split_second(el, remove_empty=False))
 
         # Get time periods and rooms
         time_periods = []
@@ -64,16 +66,12 @@ def import_lessons(
         for el in raw_time_data_2:
             weekday = int(el[1]) - 1
             hour = int(el[2])
-            room_ids = list(filter(lambda r: r != "", el[3].split(";")))
+            room_ids = untis_split_third(el[3], conv=int)
 
             # Get rooms
             rooms = []
             for room_id in room_ids:
-                if room_id and room_id != "0":
-                    room_id = int(room_id)
-                    r = rooms_ref[room_id]
-                else:
-                    r = None
+                r = rooms_ref[room_id]
                 rooms.append(r)
 
             # Get time period
@@ -84,7 +82,7 @@ def import_lessons(
         # Split data more (~)
         raw_lesson_data_2 = []
         for el in raw_lesson_data:
-            raw_lesson_data_2.append(el.split("~"))
+            raw_lesson_data_2.append(untis_split_second(el, remove_empty=False))
 
         use_room_idx = 0
         current_teacher_id = None
@@ -139,7 +137,6 @@ def import_lessons(
                     if compare_m2m(course_classes, found_group.parent_groups.all()) and compare_m2m(
                         teachers, found_group.owners.all()
                     ):
-                        match = True
                         course_group = found_group
                         logger.info(
                             "    Course group found by searching by parent groups, "
@@ -147,7 +144,7 @@ def import_lessons(
                         )
 
                 if (
-                    not match
+                    not course_group
                     and get_site_preferences()["untis_mysql__course_groups_fuzzy_matching"]
                 ):
                     if qs.count() != 1:
@@ -158,16 +155,14 @@ def import_lessons(
                     else:
                         for found_group in qs:
                             if compare_m2m(teachers, found_group.owners.all()):
-                                if match:
+                                if course_group:
                                     logger.warning(
                                         "    More than one course group found "
                                         "by searching by parent groups, "
                                         "teachers (owners) and subject (fuzzy matching mode)"
                                     )
-                                    match = False
                                     course_group = None
                                 else:
-                                    match = True
                                     course_group = found_group
                                     logger.info(
                                         "    Course group found by searching by parent groups, "
